#!/bin/bash

#The main purpose of this script "stcd.sh" is to inform of many changes in a directory, by comparing to an oldest save of the subtree defined by this directory
#It can inform of deleted, added or modified files.
#In case of added or modified files, the date of creation/modification is also printed on the standard output.
#A file is considered modified only if its date of modification changed. This scripts doesn't compare the contains of each file.

#The first parameter ($1) is the file which contains the old save of the subtree
#The second parameter ($2), can be ommitted, and represents the directory to compare to the old save. If ommited, the current directory is used.  


#--------------------#
#  error management  #
#--------------------#
#If no parameter was given
if [ $# = 0 ]; then
	echo "No parameter found : Please enter at least a file to compare the actual subtree of the current directory"

#If the file to which the script compares the actual subtree doesn't exist
elif [ ! -e "$1" ]; then 
	echo "Error : $1 doesn't exist ! -> please enter a valid name of file"

#If the file to which the script compares the actual subtree is not really a file
elif [ ! -f "$1" ]; then
	echo "Error : $1 is a directory ! -> please enter a valid name of FILE"

#If the directory to compare to the old saving is not really a directory (and not ommited)
elif [ ! -d "$2" ] && [ ! $# = 1 ]; then
	echo "Error : $2 isn't an existing directoy ! -> please enter a valid name of DIRECTORY"




#---------------------------#
#  Main part of the script  #
#---------------------------#
else
	#Generation of the new subtree and saving in a temporary file	
	./sts.sh $2 > /tmp/stcd_$$.txt


	#--------------------#
	#   Files deleted    #
	#--------------------#
	# Reading, line by line, of the formatted file containing the old saving of the subtree.
	# For each name found, searching in the new subtree for the same name. If not found, (grep is not success, the part behind || is executed) a message is displayed
	# If the name is found (the part behind || isn't executed) and grep doesn't print nothing, thanks to the parameter -q (quiet)
	cat $1 |
	while read _date1 _heure1 _gmt1 _nom1
	do
	    	cat /tmp/stcd_$$.txt | grep "$_nom1" -q || echo "  ---File deleted  : $_nom1"
	done


	#--------------------#
	#    Files added     #
	#--------------------#
	#Similar to the searching of deleted file, but reading the new subtree first and comparing names to the old, to detect added files.
	cat /tmp/stcd_$$.txt |
	while read _date2 _heure2 _gmt2 _nom2
	do
	    	cat $1 | grep "$_nom2" -q || echo "  +++File added    : $_nom2	[added the $_date2 at $_heure2]"
	done


	#--------------------#
	#   Files modified   #
	#--------------------#
	#Similar to the searching of added file, but if a name is found in both files, the scripts compares the entire line (name and date)
	#If they don't match, the files was modified (not the same dates), and a message is printed to the standard output
	#Else, nothing is printed
	cat $1 |
	while read _date1 _heure1 _gmt1 _nom1
	do
	    	cat /tmp/stcd_$$.txt | grep "$_nom1" -q
		#If the grep of the name successed
		if [ $? -eq 0 ]; then
	    		cat /tmp/stcd_$$.txt | grep "$_date1 $_heure1 $_gmt1   $_nom1" -q || echo "  ~=~File modified : $_nom1	[modified the $_date1 at $_heure1] " 
		fi
	done	
fi
